#
# spec file for package sysfsutils
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           sysfsutils
Version:        2.1.1
Release:        1.11
Summary:        System Utilities Package / Libsysfs
License:        LGPL-2.1-or-later
Group:          Development/Libraries/C and C++
URL:            https://github.com/linux-ras/sysfsutils
Source:         sysfsutils-2_1_1.tar.gz
Provides:       libsysfs
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libtool
BuildRequires:  make

%description
This package's purpose is to provide a library for interfacing with the
kernel's sys filesystem mounted at /sys. The library was an attempt to
create a stable interface to sysfs, but it failed. It is still provided
for the current users, but no new software should use this library.

%package -n libsysfs2
Summary:        Library for interfacing with the kernel's sysfs filesystem
Group:          System/Libraries

%description -n libsysfs2
This package's purpose is to provide a library for interfacing with the
kernel's sys filesystem mounted at /sys. The library was an attempt to
create a stable interface to sysfs, but it failed. It is still provided
for the current users, but no new software should use this library.

%package devel
Summary:        Development files for libsysfs
Group:          Development/Libraries/C and C++
Requires:       libsysfs2 = %{version}

%description devel
Libsysfs's purpose is to provide a library for interfacing with the
kernel's sys filesystem mounted at /sys. The library was an attempt to
create a stable interface to sysfs, but it failed. It is still provided
for the current users, but no new software should use this library.

This package contains the development files for libsysfs.

%prep
%autosetup -p1

%build
%global optflags %{optflags} -fcommon
autoreconf -fi
%configure --disable-static
%make_build

%install
%make_install
rm -v %{buildroot}/%{_libdir}/libsysfs.la
# don't install the tools
rm -f %{buildroot}/%{_bindir}/dlist_test
rm -f %{buildroot}/%{_bindir}/get_device
rm -f %{buildroot}/%{_bindir}/get_driver
rm -f %{buildroot}/%{_bindir}/get_module
rm -f %{buildroot}/%{_bindir}/testlibsysfs

%post   -n libsysfs2 -p /sbin/ldconfig
%postun -n libsysfs2 -p /sbin/ldconfig

%files
%{_bindir}/systool
%{_mandir}/man1/systool.1.gz

%files -n libsysfs2
%{_libdir}/libsysfs.so.*
%doc README
%license COPYING

%files devel
%dir %{_includedir}/sysfs
%{_includedir}/sysfs/libsysfs.h
%{_includedir}/sysfs/dlist.h
%{_libdir}/libsysfs.so
%{_libdir}/pkgconfig/libsysfs.pc

%changelog
* Wed Jun  2 2021 Jan Engelhardt <jengelh@inai.de>
- Drop old rpm constructs and sections.
- Implement shared library packaging guideline.
* Tue Jun  1 2021 Lee Duncan <lduncan@suse.com>
- Updated to version 2.1.1 from upstream, mostly build changes,
  including:
  * Bump the release version in missing file
  * sysfsutils: bump to version 2.1.1
  * build: update the bug reporting URL to github
  * Build: remove Changelog and NEWS files
  * build: don't fail on missing standard files
  * Rename dprintf() debugging macro do debugprintf()
  * build: Fix out-of-tree builds
  * build: Move test program into check_PROGRAMS
  * build: Add silent rule support for test.h generation
  * build: Add a pkg-config file
  * test/libsysfs.conf: remove the obsolete build requirement
  * build: Add missing dependencies for test.h
  * build: Remove unused configure macros
  * build: Use = instead of == in test
  * Check that sysfs is actually mounted in sysfs_get_mnt_path() and fail if not
  * test: Fix formatting
  * man: Improve systool(1) man page
  * build: Add support for specifying the pci.ids database pathname
  * build: Include "config.h" as the first header in all source files
  * build: Build the testlibsysfs program
  * build: Enable silent build rules
  * build: Quote m4 macro arguments
  * build: Use AC_CONFIG_HEADERS instead of deprecated AM_CONFIG_HEADER
  * build: Update libtool support
  * build: Use *_CPPFLAGS instead of deprecated INCLUDES variables
  * build: Update gitignore files
  * build: Remove autogenerated files
  * build: Remove obsolete CVS support in dist-hook
  * build: Add new script to bootstrap the source
  * build: Add missing declaration for m4 macro directory
  * lib/sysfs_class: fix build failure reported on GCC-11
  * TravisCI: enable build test
  * fix bug in sysfs_get_link - RHBZ #447220/Debian Bug #481015
  * use gnu.org license files to correct addresses etc
  * GPLv2 applies not just to test dir
  This removed the need for sysfsutils-latest-changes.diff.gz, since
  all of the changes in that diff were from upstream, and we have
  the latest from upstream, which has all of those fixes.
- Updated the SPEC file to add build requirements, change files
  delivered, etc, as needed by this new version of sysfs utilities.
  Also, removed baselibs.conf from SPEC file and package: not used.
* Fri Jul 10 2020 Lee Duncan <lduncan@suse.com>
- Updated to latest upstream, not yet tagged, by updating
  sysfsutils-latest-changes.diff.gz. This adds the following
  commits:
  * Limit cdev name length comparsion to strlen()+1
  * Fix issue with sysfs name comparisons.
  * config.guess: linux - Add support for ppc64le machine
  * path_is_file() should call stat(), not lstat()
  * Ignore all cscope-generated files.
  * Add a SUSE-specific libsysfs.conf.
  * Use stat() not lstat() to find link target.
  * Ignore more build files
  * Fix more string issues for gcc-10
  * Fix compiler complaint about string truncation.
  * Fix compiler complain about multiple defs of my_stdout.
  * Added ChangeLog entry for previous commits.
  * Ignore various build files.
  * fix of FUNC_TABLE_SIZE mentioned in prev commit
  * Various changes to make gcc-7 happy.
  * README: Update reporting bugs/contributions section
  This removed the need for the 3 patches added previously,
  now removed:
  * 0001-Fix-compiler-complain-about-multiple-defs-of-my_stdo.patch
  * 0002-Fix-compiler-complaint-about-string-truncation.patch
  * 0003-Fix-more-string-issues-for-gcc-10.patch
* Sun Jun 28 2020 Lee Duncan <lduncan@suse.com>
- Added a _service file, as per new OBS requirement
- Added a patch to bring sysfsutils up to latest upstream, which
  now is in place:
  * sysfsutils-latest-changes.diff.gz
- Added patches which have been submitted upstream but not yet
  merged:
  * 0001-Fix-compiler-complain-about-multiple-defs-of-my_stdo.patch
  * 0002-Fix-compiler-complaint-about-string-truncation.patch
  * 0003-Fix-more-string-issues-for-gcc-10.patch
  And removing a patch that's subsumed by the above patches:
  * sysfsutils-fix-compiler-issues.patch
  Lastly, replaced the hand-rolled sysfsutils-2.1.0.tar.gz with
  upstream archive file sysfsutils-sysfsutils-2_1_0.tar.gz
  (retreived with OBS download service), though the contents
  of the two are the same.
* Mon Apr 27 2020 Martin Liška <mliska@suse.cz>
- Enable -fcommon in order to fix boo#1160295.
* Mon Mar 23 2020 Martin Liška <mliska@suse.cz>
- Update sysfsutils-fix-compiler-issues.patch in order to
  fix boo#1166612.
* Fri Feb 21 2020 Lee Duncan <lduncan@suse.com>
- Fix compiler issues for this package, which hasn't been touched
  in a while. Should be no functional change. Added patch:
  * sysfsutils-fix-compiler-issues.patch
* Thu Feb 16 2012 crrodriguez@opensuse.org
- Libraries are back to %%{_libdir}, /usr merge project
* Tue Sep  7 2010 aj@suse.de
- Create devel package.
* Mon Jun 28 2010 jengelh@medozas.de
- use %%_smp_mflags
* Sat Dec 19 2009 jengelh@medozas.de
- add baselibs.conf as a source
* Tue Mar 24 2009 crrodriguez@suse.de
- remove static libraries
* Wed Jan  7 2009 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Tue May 27 2008 hare@suse.de
- Include systool binary (bnc#391754)
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Tue Jan 16 2007 hare@suse.de
- Run ldconfig on %%post (#204063)
- Do not duplicate .so symlink (#235332)
* Thu Aug 31 2006 kay.sievers@suse.de
- update to version 2.1.0
- provide only the shared lib, not the static lib, not the tools
* Thu Mar  9 2006 hare@suse.de
- Do not install testlibsysfs (#149981 - LTC21580)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Jan 12 2006 hmacht@suse.de
- also substitude libtool path in *.la file when moving libraries
  (bug #141161)
* Fri Jun 24 2005 snwint@suse.de
- move shared libs to /lib
* Fri Jun 10 2005 hare@suse.de
- initial release 1.3.0; split off from udev rpm.
